# flux-config-shared

Shared protocol and configuration definitions for Flux Config packages.

This package contains:
- JSON-RPC protocol definitions
- Daemon state models
- User configuration models
- Application configuration (AppConfig)
- Delegate configuration
- Pydantic validation models

Used by:
- flux-configd (daemon)
- flux-config-tui (TUI client)
